<template>
    <div class="container">
        <div class="header">
            <div class="title">
                <i class="title-icon"></i>
                <span class="title-text">日常养护统计</span>
            </div>
            <i class="back-icon" @click="handleReset"></i>
        </div>
        <div class="search">
            <!-- <el-date-picker
                v-model="date"
                type="daterange"
                range-separator="至"
                start-placeholder="开始日期"
                end-placeholder="结束日期"
                value-format="yyyy-MM-dd"
                @change="changeYear"
                style="margin-right: 10px"
            >
            </el-date-picker> -->
            <el-date-picker
                v-model="startTime"
                type="date"
                placeholder="请选择开始日期"
                value-format="yyyy-MM-dd"
            >
            </el-date-picker>
            <el-date-picker
                v-model="endTime"
                type="date"
                placeholder="请选择结束日期"
                value-format="yyyy-MM-dd"
            >
            </el-date-picker>
            <el-button size="small" @click="findinfo" type="primary">查询</el-button>
            <el-button size="small" @click="reset" type="plain"> 重置 </el-button>
        </div>
        <div class="table">
            <el-table
                :data="tableData"
                stripe
                v-loading="loading"
                @row-click="hanldeRowClick"
                @cell-click="handleCellClick"
                header-cell-class-name="custom-header-cell"
                cell-class-name="custom-cell"
            >
                <el-table-column label="序号" type="index" width="70" align="center">
                </el-table-column>
                <el-table-column align="center" prop="name" label="名称">
                    <template v-slot="{row}">
                        <i class="el-icon-arrow-down" style="margin-right: 10px"></i>
                        {{ row.name }}
                    </template>
                </el-table-column>
                <el-table-column
                    align="center"
                    prop="finishCount"
                    label="已完成"
                    column-key="1"
                >
                    <template v-slot="{row}">
                        {{ utils.thousandBit(row.finishCount) }}
                    </template>
                </el-table-column>
                <el-table-column
                    align="center"
                    prop="distributionCount"
                    label="派单中"
                    column-key="3"
                >
                    <template v-slot="{row}">
                        {{ utils.thousandBit(row.distributionCount) }}
                    </template></el-table-column
                >
                <el-table-column
                    align="center"
                    prop="constructionCount"
                    label="施工中"
                    column-key="4"
                >
                    <template v-slot="{row}">
                        {{ utils.thousandBit(row.constructionCount) }}
                    </template></el-table-column
                >
                <el-table-column
                    align="center"
                    prop="checkCount"
                    label="施工单位验收"
                    column-key="5"
                >
                    <template v-slot="{row}">
                        {{ utils.thousandBit(row.checkCount) }}
                    </template></el-table-column
                >
                <el-table-column
                    align="center"
                    prop="examineCount"
                    label="审核中"
                    column-key="6"
                >
                    <template v-slot="{row}">
                        {{ utils.thousandBit(row.examineCount) }}
                    </template>
                </el-table-column>
                <el-table-column
                    align="center"
                    prop="overdueCount"
                    label="已逾期"
                    column-key="2"
                >
                    <template v-slot="{row}">
                        {{ utils.thousandBit(row.overdueCount) }}
                    </template>
                </el-table-column>
                <el-table-column align="center" prop="allCount" label="总数">
                    <template v-slot="{row}">
                        {{ utils.thousandBit(row.allCount) }}
                    </template>
                </el-table-column>
                <el-table-column
                    align="center"
                    prop="finishMoney"
                    label="已完成金额(万元)"
                >
                    <template v-slot="{row}">
                        {{
                            utils.thousandBit(
                                parseFloat((row.finishMoney / 10000).toFixed(2))
                            )
                        }}
                        <!-- {{ utils.thousandBit(row.finishMoney) }} -->
                    </template>
                </el-table-column>
            </el-table>
            <div class="table-total">
                <span>{{ tableData.length + 1 }}</span>
                <span>总数</span>
                <span>{{ total.finishCount || 0 }}</span>
                <span>{{ total.distributionCount || 0 }}</span>
                <span>{{ total.constructionCount || 0 }}</span>
                <span>{{ total.checkCount || 0 }}</span>
                <span>{{ total.examineCount || 0 }}</span>
                <span>{{ total.overdueCount || 0 }}</span>
                <span>{{ total.allCount || 0 }}</span>
                <span>{{ total.finishMoney || 0 }}</span>
            </div>
        </div>
        <div class="charts">
            <div class="charts-border">
                <div class="charts_title" style="left: 25px">
                    <i class="charts_title-icon"></i>
                    <!-- 养护工单数量分析 -->
                    <span class="charts_title-text">工单数量分析</span>
                </div>
                <div id="pie" style="height: 100%; width: 100%"></div>
            </div>
            <div class="charts-border">
                <div class="charts_title">
                    <i class="charts_title-icon clumn-icon"></i>
                    <!-- 各部门工单状态&数量统计 -->
                    <span class="charts_title-text">状态&数量统计</span>
                </div>
                <div id="column" style="height: 100%; width: 100%"></div>
            </div>
        </div>
        <!-- <div class="charts">
            <div class="charts-border">
                <div class="charts_title" style="left: 60px">
                    <i class="charts_title-icon"></i>
                    <span class="charts_title-text">日常养护金额统计</span>
                </div>
                <div id="pie2" style="height: 100%; width: 100%"></div>
            </div>
        </div> -->
    </div>
</template>

<script>
import utils from '@/utils' // thousandBit格式化千分位
const BigNumber = require('bignumber.js')
import * as echarts from 'echarts'
import moment from 'moment'
export default {
    name: 'DailyMaintenance',
    data() {
        return {
            tableData: [],
            data: [],
            startTime: moment().startOf('year').format('YYYY-MM-DD'),
            endTime: moment().endOf('year').format('YYYY-MM-DD'),
            loading: false,
            cstatus: '',
            date: '',
            total: {},
            utils: utils,
            formInline: {
                companyIds: ['1419863231459102720', '1430734631036129280'],
                companyName: '',
                roadSegmentName: '',
            },
            path: '1419863231459102720,',
        }
    },
    mounted() {
        this.companyChange(['1419863231459102720', '1430734631036129280'])
    },
    created() {
        let moment = require('moment')
        let endDate = moment().endOf('year').format('YYYY-MM-DD')
        // 获取当前时间6个月前的时间
        let startDate = moment().startOf('year').format('YYYY-MM-DD')
        this.date = [startDate, endDate]
        this.loadData()
    },
    watch: {
        tableData(newVal) {
            this.total.finishCount = this.calculation('finishCount', newVal)
            this.total.distributionCount = this.calculation('distributionCount', newVal)
            this.total.constructionCount = this.calculation('constructionCount', newVal)
            this.total.checkCount = this.calculation('checkCount', newVal)
            this.total.examineCount = this.calculation('examineCount', newVal)
            this.total.overdueCount = this.calculation('overdueCount', newVal)
            this.total.allCount = this.calculation('allCount', newVal)
            // this.total.finishMoney = this.calculation('finishMoney', newVal)
            this.total.finishMoney = this.calculationWY('finishMoney', newVal)
            this.pieCharts(this.total, newVal)
            this.cloumnCharts(newVal)
        },
    },
    methods: {
        reset() {
            let moment = require('moment')
            let endDate = moment().endOf('year').format('YYYY-MM-DD')
            // 获取当前时间6个月前的时间
            let startDate = moment().startOf('year').format('YYYY-MM-DD')
            this.date = [startDate, endDate]
            this.startTime = startDate
            this.endTime = endDate
            this.loadData()
        },
        companyChange(val) {
            this.formInline.companyIds = val
            let id = (val && val[val.length - 1]) || ''
            if (!id) return
            this.$http
                .get('${yhxt}/statisticalStatement/v1/findAllRoadIds?id=' + id)
                .then((res) => {
                    let ids = res.data.value.join(',') || id || ''
                    if (!ids) {
                        this.getAmountStatisticsChart([])
                    } else {
                        this.getCountMaintenanceData(ids)
                    }
                })
        },
        getCountMaintenanceData(roadSegmentId) {
            this.$http
                .post('${yhxt}/statisticalStatement/v1/countMaintenance/new', {
                    roadSegmentId,
                })
                .then((res) => {
                    this.data = res.data.maintenanceNewVos
                    this.format(this.data)
                    this.getAmountStatisticsChart(res.data.maintenanceNewVos)
                })
        },
        format(data) {
            let total = 0
            let money = 0
            data.forEach((item) => {
                total += Number(item.pnameCount)
                money += Number(item.everyMoney)
            })
            console.log(total)
            data.forEach((item) => {
                item.percentage = (item.pnameCount / total) * 100
                item.percent = Number(((item.everyMoney / money) * 100).toFixed(2))
                item.money = (Number(item.everyMoney) / 10000).toFixed(2)
            })
        },
        /**
         * @description: 获取当前日期n个月前的日期
         * @param {String} n 几个月（为负数则表示前面的日期）
         * @return: 日期
         */
        diffMonth(n) {
            var dt = new Date()
            dt.setMonth(dt.getMonth() - Number(n))
            return dt.toLocaleString().replace(/\//g, '-')
        },
        calculation(key, arr) {
            let total = 0
            if (!key || arr.length === 0) return total
            arr.forEach((item) => {
                total += parseInt(item[key])
            })
            if (total === 0) return 0
            return utils.thousandBit(total)
        },
        calculationWY(key, arr) {
            let total = 0
            if (!key || arr.length === 0) return total
            arr.forEach((item) => {
                total += parseFloat((item[key] / 10000).toFixed(2)) * 10000
            })
            if (total === 0) return 0
            return utils.thousandBit(parseFloat((total / 10000).toFixed(2)))
        },
        changeYear(val) {
            if (!val) {
                return this.loadData()
            }
            this.loading = true
            this.$http
                .post(
                    '${yhxt}/workOrderInformation/v1/getWorkCountVo' +
                        `?startDate=${this.startTime}&endDate=${this.endTime}`
                )
                .then((res) => {
                    this.tableData = (res && res.status == 200 && res.data) || []
                    this.data = []
                    this.data.push(this.tableData)
                    this.loading = false
                })
        },
        findinfo() {
            let val = this.date
            this.loading = true
            this.$http
                .post(
                    '${yhxt}/workOrderInformation/v1/getWorkCountVo' +
                        `?startDate=${this.startTime}&endDate=${this.endTime}`
                )
                .then((res) => {
                    this.tableData = (res && res.status == 200 && res.data) || []
                    this.data = []
                    this.data.push(this.tableData)
                    this.loading = false
                })
        },
        handleReset() {
            let length = this.data.length - 1
            if (length === 0) return
            this.tableData = this.data[this.data.length - 2]
            this.data.splice(length, 1)
        },
        hanldeRowClick(row) {
            if (row.chirldren.length == 0 && row.roadId) {
                this.path += row.roadId
                return this.$router.push({
                    name: 'workOrderInfo',
                    params: {
                        value: row,
                        path: this.path,
                        cstatus: this.cstatus,
                    },
                })
            } else {
                this.path += row.id + ','
            }
            this.tableData = row.chirldren
            this.data.push(row.chirldren)
        },
        handleCellClick(row, column) {
            this.cstatus = column.columnKey
        },
        loadData() {
            this.loading = true
            let str = ''
            if (this.date) {
                str = `?startDate=${this.startTime}&endDate=${this.endTime}`
            }
            this.$http
                .post('${yhxt}/workOrderInformation/v1/getWorkCountVo' + str)
                .then((res) => {
                    this.tableData = (res && res.status == 200 && res.data) || []
                    this.data = []
                    this.data.push(this.tableData)
                    this.loading = false
                })
                .catch(() => {
                    this.loading = false
                })
        },
        pieCharts(obj, rows) {
            var chartDom = document.getElementById('pie')
            var myChart = echarts.init(chartDom)
            let data = [
                {
                    name: '已完成',
                    value: obj.finishCount || 0,
                },
                {
                    name: '派单',
                    value: obj.distributionCount || 0,
                },
                {
                    name: '施工',
                    value: obj.constructionCount || 0,
                },
                {
                    name: '验收',
                    value: obj.checkCount || 0,
                },
                {
                    name: '审核',
                    value: obj.examineCount || 0,
                },
                // {
                //   name: '已逾期',
                //   value: obj.overdueCount || 0
                // }
            ]
            let innerData = [
                {
                    name: '审核',
                    value: this.calculation('examineOverdue', rows),
                },
                {
                    name: '验收',
                    value: this.calculation('checkOverdue', rows),
                },
                {
                    name: '施工',
                    value: this.calculation('constructionOverdue', rows),
                },
                {
                    name: '派单',
                    value: this.calculation('distributionOverdue', rows),
                },
            ]
            innerData = innerData.sort((a, b) => b.value - a.value)
            innerData[0].selected = true
            var option
            let total = new BigNumber(0)
            data.forEach((item) => {
                total = total.plus(item.value)
            })
            let formatNumber = (num) => num.toString().replace(/(?=(\B)(\d{3})+$)/g, ',')
            option = {
                // title: [
                //   {
                //     text: `{name|总数/个}\n{val|${formatNumber(total)}}`,
                //     top: 'center',
                //     left: 'center',
                //     textStyle: {
                //       rich: {
                //         name: {
                //           fontSize: 14,
                //           color: '#fff',
                //           padding: [10, 0]
                //         },
                //         val: {
                //           fontSize: 32,
                //           fontWeight: 'bold',
                //           color: '#fff'
                //         }
                //       }
                //     }
                //   }
                // ],
                tooltip: {
                    trigger: 'item',
                    formatter: (a) => {
                        return `${a.marker} ${a.data.name} ${a.data.value}个 ${a.percent}%`
                    },
                },
                color: [
                    '#5b8ff9',
                    '#5ad8a6',
                    '#5d7092',
                    '#f6bd16',
                    '#6f5ef9',
                    '#6dc8ec',
                    '#945fb9',
                    '#ff9845',
                    '#1e9493',
                ],
                legend: {
                    icon: 'circle',
                    orient: 'vertical',
                    right: 25,
                    top: 'center',
                    bottom: 20,
                    textStyle: {
                        color: '#ccc',
                    },
                },
                series: [
                    {
                        type: 'pie',
                        selectedMode: 'single',
                        radius: [0, '50%'],
                        label: {
                            // show: false,
                            formatter: (a) => {
                                if (a.value > 0) {
                                    return `{name|${a.name}逾期}`
                                } else {
                                    return ''
                                }
                            },
                            minMargin: 5,
                            edgeDistance: 80,
                            rich: {
                                name: {
                                    fontSize: 12,
                                    color: '#fff',
                                },
                            },
                            position: 'inner',
                        },
                        tooltip: {
                            trigger: 'item',
                            formatter: (a) => {
                                return `${a.marker} ${a.data.name}逾期 ${a.data.value}个 ${a.percent}%`
                            },
                        },
                        labelLine: {
                            show: false,
                        },
                        data: innerData,
                    },
                    {
                        type: 'pie',
                        radius: ['40%', '60%'],
                        // center: ['45%', '50%'],
                        data: data,
                        label: {
                            alignTo: 'edge',
                            minMargin: 5,
                            edgeDistance: '15%',
                            formatter: (a) => {
                                return `{percent|${a.percent}%}`
                            },
                            rich: {
                                percent: {
                                    fontSize: 15,
                                    color: '#fff',
                                },
                            },
                        },
                    },
                ],
            }

            option && myChart.setOption(option)
        },
        cloumnCharts(data) {
            var chartDom = document.getElementById('column')
            var myChart = echarts.init(chartDom)
            var option
            let xData = []
            let finishData = []
            let distributionData = []
            let constructionData = []
            let checkData = []
            let examineData = []
            let overdueData = []
            let allData = []
            data.forEach((item) => {
                xData.push(item.name)
                finishData.push(item.finishCount)
                distributionData.push(item.distributionCount)
                constructionData.push(item.constructionCount)
                checkData.push(item.checkCount)
                examineData.push(item.examineCount)
                overdueData.push(item.overdueCount)
                allData.push(item.allCount)
            })
            option = {
                title: {
                    textStyle: {
                        color: '#fff',
                    },
                },
                grid: {
                    top: '20%',
                    left: '10%',
                    right: '10%',
                    bottom: '20%',
                },
                legend: {
                    itemHeight: 10,
                    itemWidth: 10,
                    bottom: 'bottom',
                    bottom: '8%',
                    textStyle: {
                        color: '#fff',
                    },
                },
                tooltip: {
                    trigger: 'axis',
                    axisPointer: {
                        type: 'none',
                    },
                },
                color: [
                    '#5b8ff9',
                    '#5ad8a6',
                    '#5d7092',
                    '#f6bd16',
                    '#6f5ef9',
                    '#6dc8ec',
                    '#945fb9',
                    '#ff9845',
                    '#1e9493',
                ],
                xAxis: {
                    type: 'category',
                    data: xData,
                    axisLabel: {
                        fontSize: 14,
                        color: '#B8C2CC',
                    },
                    axisTick: {
                        show: true,
                        lineStyle: {
                            color: '#B8C2CC',
                        },
                    },
                    axisLine: {
                        show: true,
                        lineStyle: {
                            color: '#274561',
                        },
                    },
                },
                yAxis: {
                    name: '单位：个',
                    nameTextStyle: {
                        color: '#B8C2CC',
                        nameLocation: 'start',
                        fontSize: 18,
                        fontWeight: 700,
                    },
                    type: 'value',
                    splitLine: {show: false}, //去除网格线
                    axisLabel: {
                        textStyle: {
                            color: '#B8C2CC',
                        },
                    },
                    axisTick: {
                        //y轴刻度线
                        show: true,
                        lineStyle: {
                            color: '#B8C2CC',
                        },
                    },
                    axisLine: {
                        //y轴
                        show: true,
                        lineStyle: {
                            color: '#274561',
                        },
                    },
                },
                series: [
                    {
                        name: '已完成',
                        type: 'bar',
                        stack: 'Ad',
                        barWidth: '15%',
                        data: finishData,
                        showBackground: true,
                        backgroundStyle: {
                            color: 'rgba(34, 73, 107, 0.5)',
                        },
                    },
                    {
                        name: '派单中',
                        type: 'bar',
                        stack: 'Ad',
                        barWidth: '15%',
                        data: distributionData,
                        showBackground: true,
                        backgroundStyle: {
                            color: 'rgba(34, 73, 107, 0.5)',
                        },
                    },
                    {
                        name: '施工中',
                        type: 'bar',
                        stack: 'Ad',
                        barWidth: '15%',
                        data: constructionData,
                        showBackground: true,
                        backgroundStyle: {
                            color: 'rgba(34, 73, 107, 0.5)',
                        },
                    },
                    {
                        name: '施工单位验收',
                        type: 'bar',
                        stack: 'Ad',
                        barWidth: '15%',
                        data: checkData,
                        showBackground: true,
                        backgroundStyle: {
                            color: 'rgba(34, 73, 107, 0.5)',
                        },
                    },
                    {
                        name: '审核中',
                        type: 'bar',
                        stack: 'Ad',
                        barWidth: '15%',
                        data: examineData,
                        showBackground: true,
                        backgroundStyle: {
                            color: 'rgba(34, 73, 107, 0.5)',
                        },
                    },
                    {
                        name: '已逾期',
                        type: 'bar',
                        stack: 'Ad',
                        barWidth: '15%',
                        data: overdueData,
                        showBackground: true,
                        backgroundStyle: {
                            color: 'rgba(34, 73, 107, 0.5)',
                        },
                    },
                    {
                        name: '总数',
                        type: 'bar',
                        stack: 'Ad',
                        barWidth: '15%',
                        data: allData,
                        showBackground: true,
                        backgroundStyle: {
                            color: 'rgba(34, 73, 107, 0.5)',
                        },
                    },
                ],
            }

            option && myChart.setOption(option)
        },
        getAmountStatisticsChart(data) {
            let chartDom = document.getElementById('pie2')
            var myChart = echarts.init(chartDom)
            let data_ = []

            data.forEach((item) => {
                data_.push({
                    value: item.percent,
                    name: item.pname,
                    money: item.money,
                    count: item.pnameCount,
                })
            })
            let option = {
                title: {
                    textStyle: {
                        color: '#fff',
                    },
                },
                legend: {
                    orient: 'vertical',
                    right: 30,
                    top: 'center',
                    bottom: 20,
                    show: false,
                    textStyle: {
                        color: '#fff',
                    },
                },
                tooltip: {
                    trigger: 'item',
                    formatter: (a) => {
                        return `${a.marker} ${a.data.name} 总额:${a.data.money}万元 占比:${a.data.value}%`
                    },
                },
                color: ['#16ffae', '#00e6f6', '#6255f8', '#0282b9'],
                series: [
                    {
                        type: 'pie',
                        radius: ['40%', '60%'],
                        data: data_,
                        // width: '75%',
                        center: ['50%', '50%'],
                        minAngle: 10, // 设置每块扇形的最小占比
                        label: {
                            alignTo: 'edge',
                            // show: false,
                            // formatter: '{name|{b}}{money|{}}\n\n{percent|{c} %}',
                            formatter: (a) => {
                                console.log(a, '333')
                                return `{name|${a.data.name}} {count|${a.data.count} 个} {money|${a.data.money} 万元} {percent|${a.data.value} %}`
                            },
                            minMargin: 5,
                            edgeDistance: 80,
                            //   lineHeight: 18,
                            rich: {
                                name: {
                                    fontSize: 18,
                                    color: '#fff',
                                },
                                money: {
                                    fontSize: 14,
                                    color: '#fff',
                                },
                                count: {
                                    fontSize: 14,
                                    color: '#fff',
                                },
                                percent: {
                                    fontSize: 14,
                                    color: '#fff',
                                },
                            },
                        },
                    },
                ],
            }

            option && myChart.setOption(option)
        },
    },
}
</script>

<style lang="scss" scoped>
/deep/ .el-date-editor {
    background-color: #103c5d;
    border: none;
}
/deep/ .el-range-separator {
    color: #fff;
}
/deep/ .el-table th.is-leaf {
    background-color: transparent !important;
}
/deep/ .el-table__row {
    background-color: #0b426e !important;
}
/deep/ .el-table__row--striped {
    background-color: #124873 !important;
}
/deep/ .el-table__header-wrapper {
    border-top-left-radius: 10px;
    border-top-right-radius: 10px;
}
/deep/ .el-table__body-wrapper {
    border-bottom-left-radius: 10px;
    border-bottom-right-radius: 10px;
}
/deep/ .el-table {
    background-color: transparent;
}
.container {
    padding: 30px;
    overflow: auto;
    box-sizing: border-box;

    .header {
        height: 59px;
        width: 100%;
        display: flex;
        justify-content: space-between;
        border-bottom: 1px solid #4d7faf;
        .title {
            display: flex;
            height: 34px;
            align-items: center;
            .title-icon {
                display: block;
                width: 28px;
                height: 28px;
                background-image: url('../../assets/img/icon-标题@2x.png');
                background-size: 100% 100%;
            }
            .title-text {
                margin-left: 5px;
                height: 34px;
                font-size: 26px;
                font-family: Microsoft YaHei, Microsoft YaHei;
                font-weight: 700;
                line-height: 34px;
                color: transparent;
                -webkit-background-clip: text;
                background-image: linear-gradient(180deg, #e5f2ff 24%, #1f5c99 100%);
            }
        }
        .back-icon {
            margin-right: 10px;
            cursor: pointer;
            display: block;
            width: 40px;
            height: 40px;
            background-size: 100% 100%;
            background-image: url(../../assets//img/icon-返回@2x.png);
        }
    }
    .search {
        margin-top: 32px;
    }
    .table {
        margin-top: 12px;
        width: 100%;
        /deep/ .custom-header-cell {
            background-color: #145080 !important;
            padding: 15px 0;
            .cell {
                font-size: 18px;
                font-family: Microsoft YaHei, Microsoft YaHei;
                font-weight: 700;
                color: #e7edf0;
            }
        }
        /deep/ .custom-cell {
            padding: 15px 0;
            cursor: pointer;
            .cell,
            div {
                font-size: 16px;
                font-family: Microsoft YaHei, Microsoft YaHei;
                font-weight: 400;
                color: #e5f2ff;
            }
        }
        .table-total {
            display: flex;
            justify-content: center;
            align-items: center;
            height: 64px;
            background-color: #145080;
            border-radius: 10px;
            margin-top: 8px;
            span {
                font-size: 18px;
                font-family: Microsoft YaHei, Microsoft YaHei;
                font-weight: 700;
                color: #e7edf0;
                text-align: center;
                &:nth-child(1) {
                    width: 70px;
                }
                &:not(:nth-child(1)) {
                    flex: 1;
                }
            }
        }
    }
    .charts {
        margin-top: 32px;
        display: flex;
        .charts-border {
            position: relative;
            height: 507px;
            flex: 1;
            background-size: 100% 100%;
            background-image: url('../../assets/img/框@2x.png');
            .charts_title {
                display: flex;
                height: 24px;
                align-items: center;
                position: absolute;
                top: 30px;
                left: 20px;
            }
            .charts_title-icon {
                display: block;
                width: 20px;
                height: 20px;
                background-size: 100% 100%;
                background-image: url('../../assets/img/icon-饼图@2x.png');
            }
            .clumn-icon {
                background-image: url('../../assets/img/icon-柱图@2x.png');
            }
            .charts_title-text {
                margin-left: 5px;
                height: 24px;
                font-size: 18px;
                font-family: Microsoft YaHei, Microsoft YaHei;
                font-weight: 700;
                line-height: 24px;
                color: transparent;
                -webkit-background-clip: text;
                background-image: linear-gradient(180deg, #e5f2ff 24%, #1f5c99 100%);
            }
        }
    }
}
</style>
